#!/bin/sh

cat << EOF

This script installs Kubernetes daemonsets for AIX nodes in the IBM Cloud Private cluster.
kubectl CLI must be configured with "admin" privileges on the node before running this script.
You can run 'cloudctl login -a https://<mycluster.icp>:8443 -u admin' for this purpose.
EOF

echo

read ANSWER?"Continue [y/N]? "
if [ "$ANSWER" != "y" -a "$ANSWER" != "Y" ]; then
	exit 0
fi

echo

echo "Checking kubectl... \c"
NENV=/tmp/calico-node.env.$$
kubectl get ds/calico-node -n kube-system -o jsonpath='{range ..env[*]}{.name}{"="}{.value}{"\n"}{end}' > $NENV
if [ $? != 0 ]; then
	echo "fail"
	exit 1
fi
echo "done"

echo

IFACE=`grep host_interface /etc/criwpard/criwpard.conf | cut -d \" -f 4`
echo "Local network interface from /etc/criwpard/criwpard.conf: $IFACE"

LOCALIP=`lsattr -El $IFACE -a netaddr -F value`
echo "Local IP address determined from network interface: $LOCALIP"

MASTER=`kubectl get nodes -l role=master -o jsonpath='{ $.items[*].status.addresses[?(@.type=="InternalIP")].address }'`
echo "Found IP address of Kubernetes master node: $MASTER"

CIDR=`grep CALICO_IPV4POOL_CIDR "$NENV" | cut -d= -f2`
echo "Found cluster CIDR: $CIDR"

IPIP=`grep CALICO_IPV4POOL_IPIP "$NENV" | cut -d= -f2`
echo "Found IP-in-IP setting: $IPIP"

rm -f "$NENV"

echo

echo "Creating /etc/cfc/pods/kube-proxy.json...\c"
sed -e "s,__IP__,$LOCALIP," -e "s,__CIDR__,$CIDR," /opt/freeware/share/kubernetes/kube-proxy.json.tmpl > /etc/cfc/pods/kube-proxy.json
if [ $? != 0 ]; then
	echo "fail"
	exit 1
fi
echo "done"

read ANSWER?"Install calico-node-aix daemonset [y/N]? "
if [ "$ANSWER" != "y" -a "$ANSWER" != "Y" ]; then
	exit 0
fi

echo "Removing calico-node-aix daemonset... \c"
kubectl delete ds/calico-node-aix -n kube-system > /dev/null
echo "done"

echo "Patching calico-node daemonset...\c"
kubectl patch ds/calico-node -n kube-system -p '{"spec":{"template":{"spec":{"nodeSelector":{"beta.kubernetes.io/os":"linux"}}}}}' > /dev/null
echo "done"

echo "Installing calico-node-aix daemonset... \c"
DSYAML=/tmp/calico-node-aix.yaml.$$
sed -e "s,__MASTER__,$MASTER," -e "s,__CIDR__,$CIDR," -e "s,__IPIP__,$IPIP," /opt/freeware/share/kubernetes/calico-node-aix.yaml.tmpl > $DSYAML
kubectl create -f $DSYAML
if [ $? != 0 ]; then
	echo "fail"
	exit 1
fi
rm -f "$DSYAML"
echo "done"
